# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: openconfig-interfaces.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='openconfig-interfaces.proto',
  package='openconfig_interfaces',
  syntax='proto3',
  serialized_options=None,
  serialized_pb=_b('\n\x1bopenconfig-interfaces.proto\x12\x15openconfig_interfaces\"\xc8\x1a\n\nInterfaces\x12>\n\tinterface\x18\x01 \x03(\x0b\x32+.openconfig_interfaces.Interfaces.Interface\x1a\xf9\x19\n\tInterface\x12\x42\n\x06\x63onfig\x18\x01 \x01(\x0b\x32\x32.openconfig_interfaces.Interfaces.Interface.Config\x12G\n\thold_time\x18\x02 \x01(\x0b\x32\x34.openconfig_interfaces.Interfaces.Interface.HoldTime\x12\x0c\n\x04name\x18\x03 \x01(\t\x12@\n\x05state\x18\x04 \x01(\x0b\x32\x31.openconfig_interfaces.Interfaces.Interface.State\x12P\n\rsubinterfaces\x18\x05 \x01(\x0b\x32\x39.openconfig_interfaces.Interfaces.Interface.Subinterfaces\x1an\n\x06\x43onfig\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x0f\n\x07\x65nabled\x18\x02 \x01(\x08\x12\x15\n\rloopback_mode\x18\x03 \x01(\x08\x12\x0b\n\x03mtu\x18\x04 \x01(\r\x12\x0c\n\x04name\x18\x05 \x01(\t\x12\x0c\n\x04type\x18\x06 \x01(\t\x1a\xe9\x01\n\x08HoldTime\x12K\n\x06\x63onfig\x18\x01 \x01(\x0b\x32;.openconfig_interfaces.Interfaces.Interface.HoldTime.Config\x12I\n\x05state\x18\x02 \x01(\x0b\x32:.openconfig_interfaces.Interfaces.Interface.HoldTime.State\x1a\"\n\x06\x43onfig\x12\x0c\n\x04\x64own\x18\x01 \x01(\r\x12\n\n\x02up\x18\x02 \x01(\r\x1a!\n\x05State\x12\x0c\n\x04\x64own\x18\x01 \x01(\r\x12\n\n\x02up\x18\x02 \x01(\r\x1a\xd2\x08\n\x05State\x12S\n\x0c\x61\x64min_status\x18\x01 \x01(\x0e\x32=.openconfig_interfaces.Interfaces.Interface.State.AdminStatus\x12L\n\x08\x63ounters\x18\x02 \x01(\x0b\x32:.openconfig_interfaces.Interfaces.Interface.State.Counters\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x0f\n\x07\x65nabled\x18\x04 \x01(\x08\x12\x0f\n\x07ifindex\x18\x05 \x01(\r\x12\x13\n\x0blast_change\x18\x06 \x01(\x04\x12\x15\n\rloopback_mode\x18\x07 \x01(\x08\x12\x0b\n\x03mtu\x18\x08 \x01(\r\x12\x0c\n\x04name\x18\t \x01(\t\x12Q\n\x0boper_status\x18\n \x01(\x0e\x32<.openconfig_interfaces.Interfaces.Interface.State.OperStatus\x12\x0c\n\x04type\x18\x0b \x01(\t\x1a\x87\x03\n\x08\x43ounters\x12\x1b\n\x13\x63\x61rrier_transitions\x18\x01 \x01(\x04\x12\x19\n\x11in_broadcast_pkts\x18\x02 \x01(\x04\x12\x13\n\x0bin_discards\x18\x03 \x01(\x04\x12\x11\n\tin_errors\x18\x04 \x01(\x04\x12\x15\n\rin_fcs_errors\x18\x05 \x01(\x04\x12\x19\n\x11in_multicast_pkts\x18\x06 \x01(\x04\x12\x11\n\tin_octets\x18\x07 \x01(\x04\x12\x17\n\x0fin_unicast_pkts\x18\x08 \x01(\x04\x12\x19\n\x11in_unknown_protos\x18\t \x01(\x04\x12\x12\n\nlast_clear\x18\n \x01(\x04\x12\x1a\n\x12out_broadcast_pkts\x18\x0b \x01(\x04\x12\x14\n\x0cout_discards\x18\x0c \x01(\x04\x12\x12\n\nout_errors\x18\r \x01(\x04\x12\x1a\n\x12out_multicast_pkts\x18\x0e \x01(\x04\x12\x12\n\nout_octets\x18\x0f \x01(\x04\x12\x18\n\x10out_unicast_pkts\x18\x10 \x01(\x04\"i\n\x0b\x41\x64minStatus\x12\x17\n\x13\x41\x64minStatus_INVALID\x10\x00\x12\x12\n\x0e\x41\x64minStatus_UP\x10\x01\x12\x14\n\x10\x41\x64minStatus_DOWN\x10\x02\x12\x17\n\x13\x41\x64minStatus_TESTING\x10\x03\"\xd1\x01\n\nOperStatus\x12\x16\n\x12OperStatus_INVALID\x10\x00\x12\x11\n\rOperStatus_UP\x10\x01\x12\x13\n\x0fOperStatus_DOWN\x10\x02\x12\x16\n\x12OperStatus_TESTING\x10\x03\x12\x16\n\x12OperStatus_UNKNOWN\x10\x04\x12\x16\n\x12OperStatus_DORMANT\x10\x05\x12\x1a\n\x16OperStatus_NOT_PRESENT\x10\x06\x12\x1f\n\x1bOperStatus_LOWER_LAYER_DOWN\x10\x07\x1a\x8b\x0c\n\rSubinterfaces\x12\\\n\x0csubinterface\x18\x01 \x03(\x0b\x32\x46.openconfig_interfaces.Interfaces.Interface.Subinterfaces.Subinterface\x1a\x9b\x0b\n\x0cSubinterface\x12]\n\x06\x63onfig\x18\x01 \x01(\x0b\x32M.openconfig_interfaces.Interfaces.Interface.Subinterfaces.Subinterface.Config\x12\r\n\x05index\x18\x02 \x01(\r\x12[\n\x05state\x18\x03 \x01(\x0b\x32L.openconfig_interfaces.Interfaces.Interface.Subinterfaces.Subinterface.State\x1a=\n\x06\x43onfig\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x0f\n\x07\x65nabled\x18\x02 \x01(\x08\x12\r\n\x05index\x18\x03 \x01(\r\x1a\x80\t\n\x05State\x12n\n\x0c\x61\x64min_status\x18\x01 \x01(\x0e\x32X.openconfig_interfaces.Interfaces.Interface.Subinterfaces.Subinterface.State.AdminStatus\x12g\n\x08\x63ounters\x18\x02 \x01(\x0b\x32U.openconfig_interfaces.Interfaces.Interface.Subinterfaces.Subinterface.State.Counters\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x0f\n\x07\x65nabled\x18\x04 \x01(\x08\x12\x0f\n\x07ifindex\x18\x05 \x01(\r\x12\r\n\x05index\x18\x06 \x01(\r\x12\x13\n\x0blast_change\x18\x07 \x01(\x04\x12\x0c\n\x04name\x18\x08 \x01(\t\x12l\n\x0boper_status\x18\t \x01(\x0e\x32W.openconfig_interfaces.Interfaces.Interface.Subinterfaces.Subinterface.State.OperStatus\x1a\x87\x03\n\x08\x43ounters\x12\x1b\n\x13\x63\x61rrier_transitions\x18\x01 \x01(\x04\x12\x19\n\x11in_broadcast_pkts\x18\x02 \x01(\x04\x12\x13\n\x0bin_discards\x18\x03 \x01(\x04\x12\x11\n\tin_errors\x18\x04 \x01(\x04\x12\x15\n\rin_fcs_errors\x18\x05 \x01(\x04\x12\x19\n\x11in_multicast_pkts\x18\x06 \x01(\x04\x12\x11\n\tin_octets\x18\x07 \x01(\x04\x12\x17\n\x0fin_unicast_pkts\x18\x08 \x01(\x04\x12\x19\n\x11in_unknown_protos\x18\t \x01(\x04\x12\x12\n\nlast_clear\x18\n \x01(\x04\x12\x1a\n\x12out_broadcast_pkts\x18\x0b \x01(\x04\x12\x14\n\x0cout_discards\x18\x0c \x01(\x04\x12\x12\n\nout_errors\x18\r \x01(\x04\x12\x1a\n\x12out_multicast_pkts\x18\x0e \x01(\x04\x12\x12\n\nout_octets\x18\x0f \x01(\x04\x12\x18\n\x10out_unicast_pkts\x18\x10 \x01(\x04\"i\n\x0b\x41\x64minStatus\x12\x17\n\x13\x41\x64minStatus_INVALID\x10\x00\x12\x12\n\x0e\x41\x64minStatus_UP\x10\x01\x12\x14\n\x10\x41\x64minStatus_DOWN\x10\x02\x12\x17\n\x13\x41\x64minStatus_TESTING\x10\x03\"\xd1\x01\n\nOperStatus\x12\x16\n\x12OperStatus_INVALID\x10\x00\x12\x11\n\rOperStatus_UP\x10\x01\x12\x13\n\x0fOperStatus_DOWN\x10\x02\x12\x16\n\x12OperStatus_TESTING\x10\x03\x12\x16\n\x12OperStatus_UNKNOWN\x10\x04\x12\x16\n\x12OperStatus_DORMANT\x10\x05\x12\x1a\n\x16OperStatus_NOT_PRESENT\x10\x06\x12\x1f\n\x1bOperStatus_LOWER_LAYER_DOWN\x10\x07\x62\x06proto3')
)



_INTERFACES_INTERFACE_STATE_ADMINSTATUS = _descriptor.EnumDescriptor(
  name='AdminStatus',
  full_name='openconfig_interfaces.Interfaces.Interface.State.AdminStatus',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='AdminStatus_INVALID', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AdminStatus_UP', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AdminStatus_DOWN', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AdminStatus_TESTING', index=3, number=3,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1588,
  serialized_end=1693,
)
_sym_db.RegisterEnumDescriptor(_INTERFACES_INTERFACE_STATE_ADMINSTATUS)

_INTERFACES_INTERFACE_STATE_OPERSTATUS = _descriptor.EnumDescriptor(
  name='OperStatus',
  full_name='openconfig_interfaces.Interfaces.Interface.State.OperStatus',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='OperStatus_INVALID', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OperStatus_UP', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OperStatus_DOWN', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OperStatus_TESTING', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OperStatus_UNKNOWN', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OperStatus_DORMANT', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OperStatus_NOT_PRESENT', index=6, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OperStatus_LOWER_LAYER_DOWN', index=7, number=7,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1696,
  serialized_end=1905,
)
_sym_db.RegisterEnumDescriptor(_INTERFACES_INTERFACE_STATE_OPERSTATUS)

_INTERFACES_INTERFACE_SUBINTERFACES_SUBINTERFACE_STATE_ADMINSTATUS = _descriptor.EnumDescriptor(
  name='AdminStatus',
  full_name='openconfig_interfaces.Interfaces.Interface.Subinterfaces.Subinterface.State.AdminStatus',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='AdminStatus_INVALID', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AdminStatus_UP', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AdminStatus_DOWN', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AdminStatus_TESTING', index=3, number=3,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1588,
  serialized_end=1693,
)
_sym_db.RegisterEnumDescriptor(_INTERFACES_INTERFACE_SUBINTERFACES_SUBINTERFACE_STATE_ADMINSTATUS)

_INTERFACES_INTERFACE_SUBINTERFACES_SUBINTERFACE_STATE_OPERSTATUS = _descriptor.EnumDescriptor(
  name='OperStatus',
  full_name='openconfig_interfaces.Interfaces.Interface.Subinterfaces.Subinterface.State.OperStatus',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='OperStatus_INVALID', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OperStatus_UP', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OperStatus_DOWN', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OperStatus_TESTING', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OperStatus_UNKNOWN', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OperStatus_DORMANT', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OperStatus_NOT_PRESENT', index=6, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OperStatus_LOWER_LAYER_DOWN', index=7, number=7,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1696,
  serialized_end=1905,
)
_sym_db.RegisterEnumDescriptor(_INTERFACES_INTERFACE_SUBINTERFACES_SUBINTERFACE_STATE_OPERSTATUS)


_INTERFACES_INTERFACE_CONFIG = _descriptor.Descriptor(
  name='Config',
  full_name='openconfig_interfaces.Interfaces.Interface.Config',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='description', full_name='openconfig_interfaces.Interfaces.Interface.Config.description', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='enabled', full_name='openconfig_interfaces.Interfaces.Interface.Config.enabled', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='loopback_mode', full_name='openconfig_interfaces.Interfaces.Interface.Config.loopback_mode', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mtu', full_name='openconfig_interfaces.Interfaces.Interface.Config.mtu', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='openconfig_interfaces.Interfaces.Interface.Config.name', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type', full_name='openconfig_interfaces.Interfaces.Interface.Config.type', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=450,
  serialized_end=560,
)

_INTERFACES_INTERFACE_HOLDTIME_CONFIG = _descriptor.Descriptor(
  name='Config',
  full_name='openconfig_interfaces.Interfaces.Interface.HoldTime.Config',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='down', full_name='openconfig_interfaces.Interfaces.Interface.HoldTime.Config.down', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='up', full_name='openconfig_interfaces.Interfaces.Interface.HoldTime.Config.up', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=727,
  serialized_end=761,
)

_INTERFACES_INTERFACE_HOLDTIME_STATE = _descriptor.Descriptor(
  name='State',
  full_name='openconfig_interfaces.Interfaces.Interface.HoldTime.State',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='down', full_name='openconfig_interfaces.Interfaces.Interface.HoldTime.State.down', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='up', full_name='openconfig_interfaces.Interfaces.Interface.HoldTime.State.up', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=763,
  serialized_end=796,
)

_INTERFACES_INTERFACE_HOLDTIME = _descriptor.Descriptor(
  name='HoldTime',
  full_name='openconfig_interfaces.Interfaces.Interface.HoldTime',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='config', full_name='openconfig_interfaces.Interfaces.Interface.HoldTime.config', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='state', full_name='openconfig_interfaces.Interfaces.Interface.HoldTime.state', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_INTERFACES_INTERFACE_HOLDTIME_CONFIG, _INTERFACES_INTERFACE_HOLDTIME_STATE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=563,
  serialized_end=796,
)

_INTERFACES_INTERFACE_STATE_COUNTERS = _descriptor.Descriptor(
  name='Counters',
  full_name='openconfig_interfaces.Interfaces.Interface.State.Counters',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='carrier_transitions', full_name='openconfig_interfaces.Interfaces.Interface.State.Counters.carrier_transitions', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='in_broadcast_pkts', full_name='openconfig_interfaces.Interfaces.Interface.State.Counters.in_broadcast_pkts', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='in_discards', full_name='openconfig_interfaces.Interfaces.Interface.State.Counters.in_discards', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='in_errors', full_name='openconfig_interfaces.Interfaces.Interface.State.Counters.in_errors', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='in_fcs_errors', full_name='openconfig_interfaces.Interfaces.Interface.State.Counters.in_fcs_errors', index=4,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='in_multicast_pkts', full_name='openconfig_interfaces.Interfaces.Interface.State.Counters.in_multicast_pkts', index=5,
      number=6, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='in_octets', full_name='openconfig_interfaces.Interfaces.Interface.State.Counters.in_octets', index=6,
      number=7, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='in_unicast_pkts', full_name='openconfig_interfaces.Interfaces.Interface.State.Counters.in_unicast_pkts', index=7,
      number=8, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='in_unknown_protos', full_name='openconfig_interfaces.Interfaces.Interface.State.Counters.in_unknown_protos', index=8,
      number=9, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='last_clear', full_name='openconfig_interfaces.Interfaces.Interface.State.Counters.last_clear', index=9,
      number=10, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='out_broadcast_pkts', full_name='openconfig_interfaces.Interfaces.Interface.State.Counters.out_broadcast_pkts', index=10,
      number=11, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='out_discards', full_name='openconfig_interfaces.Interfaces.Interface.State.Counters.out_discards', index=11,
      number=12, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='out_errors', full_name='openconfig_interfaces.Interfaces.Interface.State.Counters.out_errors', index=12,
      number=13, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='out_multicast_pkts', full_name='openconfig_interfaces.Interfaces.Interface.State.Counters.out_multicast_pkts', index=13,
      number=14, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='out_octets', full_name='openconfig_interfaces.Interfaces.Interface.State.Counters.out_octets', index=14,
      number=15, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='out_unicast_pkts', full_name='openconfig_interfaces.Interfaces.Interface.State.Counters.out_unicast_pkts', index=15,
      number=16, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1195,
  serialized_end=1586,
)

_INTERFACES_INTERFACE_STATE = _descriptor.Descriptor(
  name='State',
  full_name='openconfig_interfaces.Interfaces.Interface.State',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='admin_status', full_name='openconfig_interfaces.Interfaces.Interface.State.admin_status', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='counters', full_name='openconfig_interfaces.Interfaces.Interface.State.counters', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='description', full_name='openconfig_interfaces.Interfaces.Interface.State.description', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='enabled', full_name='openconfig_interfaces.Interfaces.Interface.State.enabled', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ifindex', full_name='openconfig_interfaces.Interfaces.Interface.State.ifindex', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='last_change', full_name='openconfig_interfaces.Interfaces.Interface.State.last_change', index=5,
      number=6, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='loopback_mode', full_name='openconfig_interfaces.Interfaces.Interface.State.loopback_mode', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mtu', full_name='openconfig_interfaces.Interfaces.Interface.State.mtu', index=7,
      number=8, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='openconfig_interfaces.Interfaces.Interface.State.name', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='oper_status', full_name='openconfig_interfaces.Interfaces.Interface.State.oper_status', index=9,
      number=10, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type', full_name='openconfig_interfaces.Interfaces.Interface.State.type', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_INTERFACES_INTERFACE_STATE_COUNTERS, ],
  enum_types=[
    _INTERFACES_INTERFACE_STATE_ADMINSTATUS,
    _INTERFACES_INTERFACE_STATE_OPERSTATUS,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=799,
  serialized_end=1905,
)

_INTERFACES_INTERFACE_SUBINTERFACES_SUBINTERFACE_CONFIG = _descriptor.Descriptor(
  name='Config',
  full_name='openconfig_interfaces.Interfaces.Interface.Subinterfaces.Subinterface.Config',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='description', full_name='openconfig_interfaces.Interfaces.Interface.Subinterfaces.Subinterface.Config.description', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='enabled', full_name='openconfig_interfaces.Interfaces.Interface.Subinterfaces.Subinterface.Config.enabled', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='index', full_name='openconfig_interfaces.Interfaces.Interface.Subinterfaces.Subinterface.Config.index', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2239,
  serialized_end=2300,
)

_INTERFACES_INTERFACE_SUBINTERFACES_SUBINTERFACE_STATE_COUNTERS = _descriptor.Descriptor(
  name='Counters',
  full_name='openconfig_interfaces.Interfaces.Interface.Subinterfaces.Subinterface.State.Counters',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='carrier_transitions', full_name='openconfig_interfaces.Interfaces.Interface.Subinterfaces.Subinterface.State.Counters.carrier_transitions', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='in_broadcast_pkts', full_name='openconfig_interfaces.Interfaces.Interface.Subinterfaces.Subinterface.State.Counters.in_broadcast_pkts', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='in_discards', full_name='openconfig_interfaces.Interfaces.Interface.Subinterfaces.Subinterface.State.Counters.in_discards', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='in_errors', full_name='openconfig_interfaces.Interfaces.Interface.Subinterfaces.Subinterface.State.Counters.in_errors', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='in_fcs_errors', full_name='openconfig_interfaces.Interfaces.Interface.Subinterfaces.Subinterface.State.Counters.in_fcs_errors', index=4,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='in_multicast_pkts', full_name='openconfig_interfaces.Interfaces.Interface.Subinterfaces.Subinterface.State.Counters.in_multicast_pkts', index=5,
      number=6, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='in_octets', full_name='openconfig_interfaces.Interfaces.Interface.Subinterfaces.Subinterface.State.Counters.in_octets', index=6,
      number=7, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='in_unicast_pkts', full_name='openconfig_interfaces.Interfaces.Interface.Subinterfaces.Subinterface.State.Counters.in_unicast_pkts', index=7,
      number=8, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='in_unknown_protos', full_name='openconfig_interfaces.Interfaces.Interface.Subinterfaces.Subinterface.State.Counters.in_unknown_protos', index=8,
      number=9, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='last_clear', full_name='openconfig_interfaces.Interfaces.Interface.Subinterfaces.Subinterface.State.Counters.last_clear', index=9,
      number=10, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='out_broadcast_pkts', full_name='openconfig_interfaces.Interfaces.Interface.Subinterfaces.Subinterface.State.Counters.out_broadcast_pkts', index=10,
      number=11, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='out_discards', full_name='openconfig_interfaces.Interfaces.Interface.Subinterfaces.Subinterface.State.Counters.out_discards', index=11,
      number=12, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='out_errors', full_name='openconfig_interfaces.Interfaces.Interface.Subinterfaces.Subinterface.State.Counters.out_errors', index=12,
      number=13, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='out_multicast_pkts', full_name='openconfig_interfaces.Interfaces.Interface.Subinterfaces.Subinterface.State.Counters.out_multicast_pkts', index=13,
      number=14, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='out_octets', full_name='openconfig_interfaces.Interfaces.Interface.Subinterfaces.Subinterface.State.Counters.out_octets', index=14,
      number=15, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='out_unicast_pkts', full_name='openconfig_interfaces.Interfaces.Interface.Subinterfaces.Subinterface.State.Counters.out_unicast_pkts', index=15,
      number=16, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1195,
  serialized_end=1586,
)

_INTERFACES_INTERFACE_SUBINTERFACES_SUBINTERFACE_STATE = _descriptor.Descriptor(
  name='State',
  full_name='openconfig_interfaces.Interfaces.Interface.Subinterfaces.Subinterface.State',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='admin_status', full_name='openconfig_interfaces.Interfaces.Interface.Subinterfaces.Subinterface.State.admin_status', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='counters', full_name='openconfig_interfaces.Interfaces.Interface.Subinterfaces.Subinterface.State.counters', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='description', full_name='openconfig_interfaces.Interfaces.Interface.Subinterfaces.Subinterface.State.description', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='enabled', full_name='openconfig_interfaces.Interfaces.Interface.Subinterfaces.Subinterface.State.enabled', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ifindex', full_name='openconfig_interfaces.Interfaces.Interface.Subinterfaces.Subinterface.State.ifindex', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='index', full_name='openconfig_interfaces.Interfaces.Interface.Subinterfaces.Subinterface.State.index', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='last_change', full_name='openconfig_interfaces.Interfaces.Interface.Subinterfaces.Subinterface.State.last_change', index=6,
      number=7, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='openconfig_interfaces.Interfaces.Interface.Subinterfaces.Subinterface.State.name', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='oper_status', full_name='openconfig_interfaces.Interfaces.Interface.Subinterfaces.Subinterface.State.oper_status', index=8,
      number=9, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_INTERFACES_INTERFACE_SUBINTERFACES_SUBINTERFACE_STATE_COUNTERS, ],
  enum_types=[
    _INTERFACES_INTERFACE_SUBINTERFACES_SUBINTERFACE_STATE_ADMINSTATUS,
    _INTERFACES_INTERFACE_SUBINTERFACES_SUBINTERFACE_STATE_OPERSTATUS,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2303,
  serialized_end=3455,
)

_INTERFACES_INTERFACE_SUBINTERFACES_SUBINTERFACE = _descriptor.Descriptor(
  name='Subinterface',
  full_name='openconfig_interfaces.Interfaces.Interface.Subinterfaces.Subinterface',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='config', full_name='openconfig_interfaces.Interfaces.Interface.Subinterfaces.Subinterface.config', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='index', full_name='openconfig_interfaces.Interfaces.Interface.Subinterfaces.Subinterface.index', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='state', full_name='openconfig_interfaces.Interfaces.Interface.Subinterfaces.Subinterface.state', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_INTERFACES_INTERFACE_SUBINTERFACES_SUBINTERFACE_CONFIG, _INTERFACES_INTERFACE_SUBINTERFACES_SUBINTERFACE_STATE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2020,
  serialized_end=3455,
)

_INTERFACES_INTERFACE_SUBINTERFACES = _descriptor.Descriptor(
  name='Subinterfaces',
  full_name='openconfig_interfaces.Interfaces.Interface.Subinterfaces',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='subinterface', full_name='openconfig_interfaces.Interfaces.Interface.Subinterfaces.subinterface', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_INTERFACES_INTERFACE_SUBINTERFACES_SUBINTERFACE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1908,
  serialized_end=3455,
)

_INTERFACES_INTERFACE = _descriptor.Descriptor(
  name='Interface',
  full_name='openconfig_interfaces.Interfaces.Interface',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='config', full_name='openconfig_interfaces.Interfaces.Interface.config', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hold_time', full_name='openconfig_interfaces.Interfaces.Interface.hold_time', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='openconfig_interfaces.Interfaces.Interface.name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='state', full_name='openconfig_interfaces.Interfaces.Interface.state', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='subinterfaces', full_name='openconfig_interfaces.Interfaces.Interface.subinterfaces', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_INTERFACES_INTERFACE_CONFIG, _INTERFACES_INTERFACE_HOLDTIME, _INTERFACES_INTERFACE_STATE, _INTERFACES_INTERFACE_SUBINTERFACES, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=134,
  serialized_end=3455,
)

_INTERFACES = _descriptor.Descriptor(
  name='Interfaces',
  full_name='openconfig_interfaces.Interfaces',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='interface', full_name='openconfig_interfaces.Interfaces.interface', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_INTERFACES_INTERFACE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=55,
  serialized_end=3455,
)

_INTERFACES_INTERFACE_CONFIG.containing_type = _INTERFACES_INTERFACE
_INTERFACES_INTERFACE_HOLDTIME_CONFIG.containing_type = _INTERFACES_INTERFACE_HOLDTIME
_INTERFACES_INTERFACE_HOLDTIME_STATE.containing_type = _INTERFACES_INTERFACE_HOLDTIME
_INTERFACES_INTERFACE_HOLDTIME.fields_by_name['config'].message_type = _INTERFACES_INTERFACE_HOLDTIME_CONFIG
_INTERFACES_INTERFACE_HOLDTIME.fields_by_name['state'].message_type = _INTERFACES_INTERFACE_HOLDTIME_STATE
_INTERFACES_INTERFACE_HOLDTIME.containing_type = _INTERFACES_INTERFACE
_INTERFACES_INTERFACE_STATE_COUNTERS.containing_type = _INTERFACES_INTERFACE_STATE
_INTERFACES_INTERFACE_STATE.fields_by_name['admin_status'].enum_type = _INTERFACES_INTERFACE_STATE_ADMINSTATUS
_INTERFACES_INTERFACE_STATE.fields_by_name['counters'].message_type = _INTERFACES_INTERFACE_STATE_COUNTERS
_INTERFACES_INTERFACE_STATE.fields_by_name['oper_status'].enum_type = _INTERFACES_INTERFACE_STATE_OPERSTATUS
_INTERFACES_INTERFACE_STATE.containing_type = _INTERFACES_INTERFACE
_INTERFACES_INTERFACE_STATE_ADMINSTATUS.containing_type = _INTERFACES_INTERFACE_STATE
_INTERFACES_INTERFACE_STATE_OPERSTATUS.containing_type = _INTERFACES_INTERFACE_STATE
_INTERFACES_INTERFACE_SUBINTERFACES_SUBINTERFACE_CONFIG.containing_type = _INTERFACES_INTERFACE_SUBINTERFACES_SUBINTERFACE
_INTERFACES_INTERFACE_SUBINTERFACES_SUBINTERFACE_STATE_COUNTERS.containing_type = _INTERFACES_INTERFACE_SUBINTERFACES_SUBINTERFACE_STATE
_INTERFACES_INTERFACE_SUBINTERFACES_SUBINTERFACE_STATE.fields_by_name['admin_status'].enum_type = _INTERFACES_INTERFACE_SUBINTERFACES_SUBINTERFACE_STATE_ADMINSTATUS
_INTERFACES_INTERFACE_SUBINTERFACES_SUBINTERFACE_STATE.fields_by_name['counters'].message_type = _INTERFACES_INTERFACE_SUBINTERFACES_SUBINTERFACE_STATE_COUNTERS
_INTERFACES_INTERFACE_SUBINTERFACES_SUBINTERFACE_STATE.fields_by_name['oper_status'].enum_type = _INTERFACES_INTERFACE_SUBINTERFACES_SUBINTERFACE_STATE_OPERSTATUS
_INTERFACES_INTERFACE_SUBINTERFACES_SUBINTERFACE_STATE.containing_type = _INTERFACES_INTERFACE_SUBINTERFACES_SUBINTERFACE
_INTERFACES_INTERFACE_SUBINTERFACES_SUBINTERFACE_STATE_ADMINSTATUS.containing_type = _INTERFACES_INTERFACE_SUBINTERFACES_SUBINTERFACE_STATE
_INTERFACES_INTERFACE_SUBINTERFACES_SUBINTERFACE_STATE_OPERSTATUS.containing_type = _INTERFACES_INTERFACE_SUBINTERFACES_SUBINTERFACE_STATE
_INTERFACES_INTERFACE_SUBINTERFACES_SUBINTERFACE.fields_by_name['config'].message_type = _INTERFACES_INTERFACE_SUBINTERFACES_SUBINTERFACE_CONFIG
_INTERFACES_INTERFACE_SUBINTERFACES_SUBINTERFACE.fields_by_name['state'].message_type = _INTERFACES_INTERFACE_SUBINTERFACES_SUBINTERFACE_STATE
_INTERFACES_INTERFACE_SUBINTERFACES_SUBINTERFACE.containing_type = _INTERFACES_INTERFACE_SUBINTERFACES
_INTERFACES_INTERFACE_SUBINTERFACES.fields_by_name['subinterface'].message_type = _INTERFACES_INTERFACE_SUBINTERFACES_SUBINTERFACE
_INTERFACES_INTERFACE_SUBINTERFACES.containing_type = _INTERFACES_INTERFACE
_INTERFACES_INTERFACE.fields_by_name['config'].message_type = _INTERFACES_INTERFACE_CONFIG
_INTERFACES_INTERFACE.fields_by_name['hold_time'].message_type = _INTERFACES_INTERFACE_HOLDTIME
_INTERFACES_INTERFACE.fields_by_name['state'].message_type = _INTERFACES_INTERFACE_STATE
_INTERFACES_INTERFACE.fields_by_name['subinterfaces'].message_type = _INTERFACES_INTERFACE_SUBINTERFACES
_INTERFACES_INTERFACE.containing_type = _INTERFACES
_INTERFACES.fields_by_name['interface'].message_type = _INTERFACES_INTERFACE
DESCRIPTOR.message_types_by_name['Interfaces'] = _INTERFACES
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Interfaces = _reflection.GeneratedProtocolMessageType('Interfaces', (_message.Message,), {

  'Interface' : _reflection.GeneratedProtocolMessageType('Interface', (_message.Message,), {

    'Config' : _reflection.GeneratedProtocolMessageType('Config', (_message.Message,), {
      'DESCRIPTOR' : _INTERFACES_INTERFACE_CONFIG,
      '__module__' : 'openconfig_interfaces_pb2'
      # @@protoc_insertion_point(class_scope:openconfig_interfaces.Interfaces.Interface.Config)
      })
    ,

    'HoldTime' : _reflection.GeneratedProtocolMessageType('HoldTime', (_message.Message,), {

      'Config' : _reflection.GeneratedProtocolMessageType('Config', (_message.Message,), {
        'DESCRIPTOR' : _INTERFACES_INTERFACE_HOLDTIME_CONFIG,
        '__module__' : 'openconfig_interfaces_pb2'
        # @@protoc_insertion_point(class_scope:openconfig_interfaces.Interfaces.Interface.HoldTime.Config)
        })
      ,

      'State' : _reflection.GeneratedProtocolMessageType('State', (_message.Message,), {
        'DESCRIPTOR' : _INTERFACES_INTERFACE_HOLDTIME_STATE,
        '__module__' : 'openconfig_interfaces_pb2'
        # @@protoc_insertion_point(class_scope:openconfig_interfaces.Interfaces.Interface.HoldTime.State)
        })
      ,
      'DESCRIPTOR' : _INTERFACES_INTERFACE_HOLDTIME,
      '__module__' : 'openconfig_interfaces_pb2'
      # @@protoc_insertion_point(class_scope:openconfig_interfaces.Interfaces.Interface.HoldTime)
      })
    ,

    'State' : _reflection.GeneratedProtocolMessageType('State', (_message.Message,), {

      'Counters' : _reflection.GeneratedProtocolMessageType('Counters', (_message.Message,), {
        'DESCRIPTOR' : _INTERFACES_INTERFACE_STATE_COUNTERS,
        '__module__' : 'openconfig_interfaces_pb2'
        # @@protoc_insertion_point(class_scope:openconfig_interfaces.Interfaces.Interface.State.Counters)
        })
      ,
      'DESCRIPTOR' : _INTERFACES_INTERFACE_STATE,
      '__module__' : 'openconfig_interfaces_pb2'
      # @@protoc_insertion_point(class_scope:openconfig_interfaces.Interfaces.Interface.State)
      })
    ,

    'Subinterfaces' : _reflection.GeneratedProtocolMessageType('Subinterfaces', (_message.Message,), {

      'Subinterface' : _reflection.GeneratedProtocolMessageType('Subinterface', (_message.Message,), {

        'Config' : _reflection.GeneratedProtocolMessageType('Config', (_message.Message,), {
          'DESCRIPTOR' : _INTERFACES_INTERFACE_SUBINTERFACES_SUBINTERFACE_CONFIG,
          '__module__' : 'openconfig_interfaces_pb2'
          # @@protoc_insertion_point(class_scope:openconfig_interfaces.Interfaces.Interface.Subinterfaces.Subinterface.Config)
          })
        ,

        'State' : _reflection.GeneratedProtocolMessageType('State', (_message.Message,), {

          'Counters' : _reflection.GeneratedProtocolMessageType('Counters', (_message.Message,), {
            'DESCRIPTOR' : _INTERFACES_INTERFACE_SUBINTERFACES_SUBINTERFACE_STATE_COUNTERS,
            '__module__' : 'openconfig_interfaces_pb2'
            # @@protoc_insertion_point(class_scope:openconfig_interfaces.Interfaces.Interface.Subinterfaces.Subinterface.State.Counters)
            })
          ,
          'DESCRIPTOR' : _INTERFACES_INTERFACE_SUBINTERFACES_SUBINTERFACE_STATE,
          '__module__' : 'openconfig_interfaces_pb2'
          # @@protoc_insertion_point(class_scope:openconfig_interfaces.Interfaces.Interface.Subinterfaces.Subinterface.State)
          })
        ,
        'DESCRIPTOR' : _INTERFACES_INTERFACE_SUBINTERFACES_SUBINTERFACE,
        '__module__' : 'openconfig_interfaces_pb2'
        # @@protoc_insertion_point(class_scope:openconfig_interfaces.Interfaces.Interface.Subinterfaces.Subinterface)
        })
      ,
      'DESCRIPTOR' : _INTERFACES_INTERFACE_SUBINTERFACES,
      '__module__' : 'openconfig_interfaces_pb2'
      # @@protoc_insertion_point(class_scope:openconfig_interfaces.Interfaces.Interface.Subinterfaces)
      })
    ,
    'DESCRIPTOR' : _INTERFACES_INTERFACE,
    '__module__' : 'openconfig_interfaces_pb2'
    # @@protoc_insertion_point(class_scope:openconfig_interfaces.Interfaces.Interface)
    })
  ,
  'DESCRIPTOR' : _INTERFACES,
  '__module__' : 'openconfig_interfaces_pb2'
  # @@protoc_insertion_point(class_scope:openconfig_interfaces.Interfaces)
  })
_sym_db.RegisterMessage(Interfaces)
_sym_db.RegisterMessage(Interfaces.Interface)
_sym_db.RegisterMessage(Interfaces.Interface.Config)
_sym_db.RegisterMessage(Interfaces.Interface.HoldTime)
_sym_db.RegisterMessage(Interfaces.Interface.HoldTime.Config)
_sym_db.RegisterMessage(Interfaces.Interface.HoldTime.State)
_sym_db.RegisterMessage(Interfaces.Interface.State)
_sym_db.RegisterMessage(Interfaces.Interface.State.Counters)
_sym_db.RegisterMessage(Interfaces.Interface.Subinterfaces)
_sym_db.RegisterMessage(Interfaces.Interface.Subinterfaces.Subinterface)
_sym_db.RegisterMessage(Interfaces.Interface.Subinterfaces.Subinterface.Config)
_sym_db.RegisterMessage(Interfaces.Interface.Subinterfaces.Subinterface.State)
_sym_db.RegisterMessage(Interfaces.Interface.Subinterfaces.Subinterface.State.Counters)


# @@protoc_insertion_point(module_scope)



#
#   pmacct (Promiscuous mode IP Accounting package)
#   pmacct is Copyright (C) 2003-2020 by Paolo Lucente
#
#   This program is free software; you can redistribute it and/or modify
#   it under the terms of the GNU General Public License as published by
#   the Free Software Foundation; either version 2 of the License, or
#   (at your option) any later version.
#
#   This program is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY; without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#   GNU General Public License for more details.
#
#   You should have received a copy of the GNU General Public License
#   along with this program; if not, write to the Free Software
#   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
#
#   pmgrpcd and its components are Copyright (C) 2018-2020 by:
#
#   Matthias Arnold <matthias.arnold@swisscom.com>
#   Raphaël P. Barazzutti <raphael@barazzutti.net>
#   Juan Camilo Cardona <jccardona82@gmail.com>
#   Thomas Graf <thomas.graf@swisscom.com>
#   Paolo Lucente <paolo@pmacct.net>
#
from optparse import OptionParser
import configparser
import os
from datetime import datetime
import sys

# TODO we'll move the next into more appropiate places
from lib_pmgrpcd import (
    SCRIPTVERSION,
    init_pmgrpcdlog,
    PMGRPCDLOG,
    FileNotFound,
    init_serializelog,
    signalhandler,
)
import lib_pmgrpcd
import signal

from concurrent import futures
# gRPC and Protobuf imports
import grpc
import cisco_grpc_dialout_pb2_grpc
import huawei_grpc_dialout_pb2_grpc
import time
from config import configure
from file_modules.file_input import FileInput
from pathlib import Path
import os
# from gnmi_pmgrpcd import GNMIClient
from kafka_modules.kafka_avro_exporter import manually_serialize

_ONE_DAY_IN_SECONDS = 60 * 60 * 24

# This is the default location for auxiliary files (config, gmaps, and others)
FOLDER_EXTRA_FILES = Path("config_files")
ABSOLUTE_FILE = Path(__file__).resolve()
CONFIGDIR = ABSOLUTE_FILE.parent / FOLDER_EXTRA_FILES
DEFAULT_CONFIGFILE = CONFIGDIR / "telemetry.conf"
CONFIGFILE = str(DEFAULT_CONFIGFILE)

# Config arguments
# There seems to be no maintained library allowing for env-config-arg configuration.
# We are simulating this here using the next function:
# Inspired by https://stackoverflow.com/questions/10551117/setting-options-from-environment-variables-when-using-argparse
class OptionParserEnv(OptionParser):
    def add_option(self, *arg, **kargs):
        envvar = kargs.get("env_name", None)
        try:
            del kargs["env_name"]
        except:
            pass
        can_be_none = kargs.get("can_be_none", False)
        try:
            del kargs["can_be_none"]
        except:
            pass

        if envvar is not None:
            new_help = kargs.get("help", "")
            new_help = new_help + " [Env variable {}]".format(envvar)
            kargs["help"] = new_help
            # Modify the default to be the one ine the env_name
            if envvar in os.environ:
                PMGRPCDLOG.debug("Getting data from %s from the env variable %s", arg[0], envvar)
                kargs["default"] = os.environ[envvar] 
            if not can_be_none and "default" in kargs and kargs["default"] is None:
                raise Exception("Parameter with env %s is None", envvar)
        super().add_option(*arg, **kargs)

def main():
    global CONFIGFILE
    usage_str = "%prog [options]"
    version_str = "%prog " + SCRIPTVERSION

    # We go over arguments very simply and obtaining the config file, if this one is available.
    config_file_flag = "-c"
    extra_argv = sys.argv[1:]
    config_file_args = None
    if extra_argv:
        if config_file_flag in extra_argv:
            index = extra_argv.index(config_file_flag)
            file_index = index + 1
            try:
                config_file_args =  extra_argv[file_index]
            except:
                pass
    if config_file_args is not None:
        CONFIGFILE = config_file_args

    # Load config.  And make sure other files exists.
    config = configparser.ConfigParser()
    if os.path.isfile(CONFIGFILE):
        config.read(CONFIGFILE)
        if "PMGRPCD" not in config.sections():
            raise FileNotFound("There is no PMGRPCD on configuration file")
    else:
        raise FileNotFound(
            "We could not find configuration file in {}".format(CONFIGFILE)
        )


    # Parse arguments. Default must be a named argument!
    parser = OptionParserEnv(usage=usage_str, version=version_str)
    # the next one is not really used, but important to avoid errors.
    parser.add_option(
        config_file_flag,
        default=str(DEFAULT_CONFIGFILE),
        dest="configuration",
        help="Path to configuration file",
    )
    #gnmi options
    #parser.add_option(
    #    "-g",
    #    "--gnmi_enable",
    #    default=config.getboolean("PMGRPCD", "gnmi_enable", fallback=False),
    #    help="Boolean defining whether gnmi is enable (this disables the rest of collectrors)",
    #)
    #parser.add_option(
    #    "--gnmi_target",
    #    env_name = "GNMI_SERVER",
    #    default=config.get("PMGRPCD", "gnmi_target", fallback=None),
    #    help="The url of the gnmi target",
    #)

    parser.add_option(
        "-T",
        "--topic",
        env_name = "PM_TOPIC",
        default=config.get("PMGRPCD", "topic", fallback=None),
        dest="topic",
        help="the json data are serialized to this topic",
    )
    parser.add_option(
        "-B",
        "--bsservers",
        default=config.get("PMGRPCD", "bsservers", fallback=None),
        env_name = "BSSERVERS",
        dest="bsservers",
        help="bootstrap servers url with port to reach kafka",
    )
    parser.add_option(
        "-S",
        "--secproto",
        default=config.get("PMGRPCD", "secproto", fallback="ssl"),
        dest="secproto",
        help="security protocol (is normaly ssl)",
    )
    parser.add_option(
        "-O",
        "--sslcertloc",
        env_name = "SSLCERTLOC",
        default=config.get("PMGRPCD", "sslcertloc", fallback=None),
        dest="sslcertloc",
        help="path/file to ssl certification location",
    )
    parser.add_option(
        "-K",
        "--sslkeyloc",
        env_name = "SSLKEYLOC",
        default=config.get("PMGRPCD", "sslkeyloc", fallback=None),
        dest="sslkeyloc",
        help="path/file to ssl key location",
    )
    parser.add_option(
        "-U",
        "--urlscreg",
        env_name="URLSCREG",
        default=config.get("PMGRPCD", "urlscreg", fallback=None),
        dest="urlscreg",
        help="the url to the schema-registry",
    )
    parser.add_option(
        "-L",
        "--calocation",
        env_name="CALOCATION",
        default=config.get("PMGRPCD", "calocation", fallback=None),
        dest="calocation",
        help="the ca_location used to connect to schema-registry",
    )
    parser.add_option(
        "-G",
        "--gpbmapfile",
        env_name="GPBMAPFILE",
        default=config.get("PMGRPCD", "gpbmapfile", fallback=None),
        dest="gpbmapfile",
        help="change path/name of gpbmapfile [default: %default]",
    )
    parser.add_option(
        "-M",
        "--avscmapfile",
        env_name="AVSCMALFILE",
        default=config.get("PMGRPCD", "avscmapfile", fallback=None),
        dest="avscmapfile",
        help="path/name to the avscmapfile",
    )
    parser.add_option(
        "-m",
        "--mitigation",
        action="store_true",
        default=config.getboolean("PMGRPCD", "mitigation"),
        dest="mitigation",
        help="enable plugin mitigation mod_result_dict from python module mitigation.py",
    )
    parser.add_option(
        "-d",
        "--debug",
        action="store_true",
        default=config.getboolean("PMGRPCD", "debug"),
        dest="debug",
        help="enable debug messages on the logfile",
    )
    parser.add_option(
        "-l",
        "--PMGRPCDLOGfile",
        default=config.get("PMGRPCD", "PMGRPCDLOGfile"),
        dest="PMGRPCDLOGfile",
        help="PMGRPCDLOGfile the logfile on the collector face with path/name [default: %default]",
    )
    parser.add_option(
        "-a",
        "--serializelogfile",
        default=config.get("PMGRPCD", "serializelogfile"),
        dest="serializelogfile",
        help="serializelogfile with path/name for kafka avro and zmq messages [default: %default]",
    )
    parser.add_option(
        "-I",
        "--ipport",
        action="store",
        type="string",
        default=config.get("PMGRPCD", "ipport"),
        dest="ipport",
        help="change the ipport the daemon is listen on [default: %default]",
    )
    parser.add_option(
        "-w",
        "--workers",
        action="store",
        type="int",
        default=config.get("PMGRPCD", "workers"),
        dest="workers",
        help="change the nr of paralell working processes [default: %default]",
    )
    parser.add_option(
        "-b",
        "--processpool",
        action="store",
        type="int",
        default=config.get("PMGRPCD", "processpool"),
        dest="ProcessPool",
        help="change the nr of processes within the ProcessPool of Kafka [default: %default]",
    )
    parser.add_option(
        "-C",
        "--cisco",
        action="store_true",
        default=config.getboolean("PMGRPCD", "cisco"),
        dest="cisco",
        help="enable the grpc messages comming from Cisco [default: %default]",
    )
    parser.add_option(
        "-H",
        "--huawei",
        action="store_true",
        default=config.getboolean("PMGRPCD", "huawei"),
        dest="huawei",
        help="enable the grpc messages comming from Huawei [default: %default]",
    )
    parser.add_option(
        "-t",
        "--cenctype",
        action="store",
        type="string",
        default=config.get("PMGRPCD", "cenctype"),
        dest="cenctype",
        help="cenctype is the type of encoding for cisco. This is because some protofiles are incompatible. With cenctype=gpbkv only cisco is enabled. The encoding type can be json, gpbcomp, gpbkv [default: %default]",
    )
    parser.add_option(
        "-e",
        "--example",
        action="store_true",
        default=config.getboolean("PMGRPCD", "example"),
        dest="example",
        help="Enable writing Example Json-Data-Files [default: %default]",
    )
    parser.add_option(
        "-E",
        "--examplepath",
        default=config.get("PMGRPCD", "examplepath"),
        dest="examplepath",
        help="dump a json example of each proto/path to this examplepath",
    )
    parser.add_option(
        "-j",
        "--jsondatadumpfile",
        dest="jsondatadumpfile",
        help="writing the output to the jsondatadumpfile path/name",
    )
    parser.add_option(
        "-r",
        "--rawdatadumpfile",
        default=config.get("PMGRPCD", "rawdatadumpfile", fallback=None),
        dest="rawdatadumpfile",
        help="writing the raw data from the routers to the rowdatafile path/name",
    )
    parser.add_option(
        "-z",
        "--zmq",
        action="store_true",
        default=config.getboolean("PMGRPCD", "zmq"),
        dest="zmq",
        help="enable forwarding to ZMQ [default: %default]",
    )
    parser.add_option(
        "-p",
        "--zmqipport",
        default=config.get("PMGRPCD", "zmqipport"),
        dest="zmqipport",
        help="define proto://ip:port of zmq socket bind [default: %default]",
    )
    parser.add_option(
        "-k",
        "--kafkaavro",
        action="store_true",
        default=config.getboolean("PMGRPCD", "kafkaavro"),
        dest="kafkaavro",
        help="enable forwarding to Kafka kafkaavro (with schema-registry) [default: %default]",
    )
    parser.add_option(
        "-o",
        "--onlyopenconfig",
        action="store_true",
        default=config.getboolean("PMGRPCD", "onlyopenconfig"),
        dest="onlyopenconfig",
        help="only accept pakets of openconfig",
    )
    parser.add_option(
        "-i", "--ip", dest="ip", help="only accept pakets of this single ip"
    )
    parser.add_option(
        "-A",
        "--avscid",
        dest="avscid",
        help="this is to serialize manually with avscid and jsondatafile (for development)",
    )
    parser.add_option(
        "-J",
        "--jsondatafile",
        dest="jsondatafile",
        help="this is to serialize manually with avscid and jsondatafile (for development)",
    )
    parser.add_option(
        "-R",
        "--rawdatafile",
        dest="rawdatafile",
        help="this is to process manually (via mitigation) process a rawdatafile with a single rawrecord (for development)",
    )
    parser.add_option(
        "-N",
        "--console",
        action="store_true",
        dest="console",
        help="this is to display all log-messages also on console (for development)",
    )
    parser.add_option(
        "-v", action="store_true", dest="version", help="print version of this script"
    )
    parser.add_option(
        "-F",
        "--no-flatten",
        action="store_false",
        default=config.getboolean("PMGRPCD", "flatten"),
        dest="flatten",
        help="disable data flattening [default: %default]",
    )
    parser.add_option(
        "-s",
        "--kafkasimple",
        default=config.getboolean("PMGRPCD", "kafkasimple", fallback=False),
        dest="kafkasimple",
        help="Boolean if kafkasimple should be enabled.",
    )

    parser.add_option(
        "--file_exporter_file",
        default=config.get("PMGRPCD", "file_exporter_file", fallback=None),
        dest="file_exporter_file",
        help="Name of file for file exporter.",
    )

    parser.add_option(
        "--file_importer_file",
        default=config.get("PMGRPCD", "file_importer_file", fallback=None),
        dest="file_importer_file",
        help="Name of the file to import. If set, we will ignore the rest of the importers.",
    )

    (lib_pmgrpcd.OPTIONS, args) = parser.parse_args()

    init_pmgrpcdlog()
    init_serializelog()

    if lib_pmgrpcd.OPTIONS.version:
        print(parser.get_version())
        raise SystemExit


    PMGRPCDLOG.info("Using %s as config file",  CONFIGFILE)
    PMGRPCDLOG.info("startoptions of this script: %s", str(lib_pmgrpcd.OPTIONS))

    # Test-Statements Logging
    # -----------------------
    # PMGRPCDLOG.debug('debug message')
    # PMGRPCDLOG.info('info message')
    # PMGRPCDLOG.warning('warn message')
    # PMGRPCDLOG.error('error message')
    # PMGRPCDLOG.critical('critical message')

    # serializelog.debug('debug message')
    # serializelog.info('info message')
    # serializelog.warning('warn message')
    # serializelog.error('error message')
    # serializelog.critical('critical message')

    configure()


    PMGRPCDLOG.info("enable listening to SIGNAL USR1 with Signalhandler")
    signal.signal(signal.SIGUSR1, signalhandler)
    PMGRPCDLOG.info("enable listening to SIGNAL USR2 with Signalhandler")
    signal.signal(signal.SIGUSR2, signalhandler)

    # I am going to comment the manually export of data from now, this could go into other script.
    if lib_pmgrpcd.OPTIONS.avscid and lib_pmgrpcd.OPTIONS.jsondatafile:
        manually_serialize()
    elif lib_pmgrpcd.OPTIONS.file_importer_file:
        file_importer = FileInput(lib_pmgrpcd.OPTIONS.file_importer_file)
        PMGRPCDLOG.info("Starting file import")
        file_importer.generate()
        PMGRPCDLOG.info("No more data, sleeping 3 secs")
        time.sleep(3)
        PMGRPCDLOG.info("Finalizing file import")
    elif lib_pmgrpcd.OPTIONS.avscid or lib_pmgrpcd.OPTIONS.jsondatafile:
        PMGRPCDLOG.info(
            "manually serialize need both lib_pmgrpcd.OPTIONS avscid and jsondatafile"
        )
        parser.print_help()
    #elif lib_pmgrpcd.OPTIONS.gnmi_enable:
    #    if lib_pmgrpcd.OPTIONS.gnmi_target is None:
    #        error = "gnmi target not configured, but gnmi enabled"
    #        PMGRPCDLOG.error(error)
    #        raise Exception(error)
    #
    #    PMGRPCDLOG.info("Starting contact with gnmi server %s. Other functions will be ignored", lib_pmgrpcd.OPTIONS.gnmi_target)
    #    channel = grpc.insecure_channel(lib_pmgrpcd.OPTIONS.gnmi_target)
    #    gnmi_client = GNMIClient(channel)
    #    breakpoint()

    else:
        # make sure some important files exist
        if not os.path.isfile(lib_pmgrpcd.OPTIONS.gpbmapfile):
            raise FileNotFound("No gpbmapfile file found in {}".format(lib_pmgrpcd.OPTIONS.gpbmapfile))

        # TODO: Do we really need this always?
        if not os.path.isfile(lib_pmgrpcd.OPTIONS.avscmapfile):
            raise FileNotFound("No avscmapfile file found in {}".format(lib_pmgrpcd.OPTIONS.avscmapfile))
        PMGRPCDLOG.info("pmgrpsd.py is started at %s", str(datetime.now()))
        serve()


def serve():

    gRPCserver = grpc.server(
        futures.ThreadPoolExecutor(max_workers=lib_pmgrpcd.OPTIONS.workers)
    )

    if lib_pmgrpcd.OPTIONS.huawei:
        if lib_pmgrpcd.OPTIONS.cenctype == 'gpbkv':
            PMGRPCDLOG.info("Huawei is disabled because cenctype=gpbkv")
        else:
            PMGRPCDLOG.info("Huawei is enabled")
            # Ugly, but we have to load just here because if not there is an exception due to a conflict between the cisco and huawei protos.
            from huawei_pmgrpcd import gRPCDataserviceServicer
            huawei_grpc_dialout_pb2_grpc.add_gRPCDataserviceServicer_to_server(
                gRPCDataserviceServicer(), gRPCserver
            )
    else:
        PMGRPCDLOG.info("Huawei is disabled")

    if lib_pmgrpcd.OPTIONS.cisco:
        PMGRPCDLOG.info("Cisco is enabled")
        # Ugly, but we have to load just here because if not there is an exception due to a conflict between the cisco and huawei protos.
        from cisco_pmgrpcd import gRPCMdtDialoutServicer
        cisco_grpc_dialout_pb2_grpc.add_gRPCMdtDialoutServicer_to_server(
            gRPCMdtDialoutServicer(), gRPCserver
        )
    else:
        PMGRPCDLOG.info("Cisco is disabled")

    gRPCserver.add_insecure_port(lib_pmgrpcd.OPTIONS.ipport)
    gRPCserver.start()

    try:
        while True:
            time.sleep(_ONE_DAY_IN_SECONDS)
    except KeyboardInterrupt:
        gRPCserver.stop(0)
        PMGRPCDLOG.info("Stopping server")
        time.sleep(1)


if __name__ == "__main__":
    main()



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

import cisco_grpc_dialout_pb2 as cisco__grpc__dialout__pb2


class gRPCMdtDialoutStub(object):
  """gRPCMdtDialout defines service used for client-side streaming pushing MdtDialoutArgs.
  """

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.MdtDialout = channel.stream_stream(
        '/mdt_dialout.gRPCMdtDialout/MdtDialout',
        request_serializer=cisco__grpc__dialout__pb2.MdtDialoutArgs.SerializeToString,
        response_deserializer=cisco__grpc__dialout__pb2.MdtDialoutArgs.FromString,
        )


class gRPCMdtDialoutServicer(object):
  """gRPCMdtDialout defines service used for client-side streaming pushing MdtDialoutArgs.
  """

  def MdtDialout(self, request_iterator, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_gRPCMdtDialoutServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'MdtDialout': grpc.stream_stream_rpc_method_handler(
          servicer.MdtDialout,
          request_deserializer=cisco__grpc__dialout__pb2.MdtDialoutArgs.FromString,
          response_serializer=cisco__grpc__dialout__pb2.MdtDialoutArgs.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'mdt_dialout.gRPCMdtDialout', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))



#
#   pmacct (Promiscuous mode IP Accounting package)
#   pmacct is Copyright (C) 2003-2020 by Paolo Lucente
#
#   This program is free software; you can redistribute it and/or modify
#   it under the terms of the GNU General Public License as published by
#   the Free Software Foundation; either version 2 of the License, or
#   (at your option) any later version.
#
#   This program is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY; without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#   GNU General Public License for more details.
#
#   You should have received a copy of the GNU General Public License
#   along with this program; if not, write to the Free Software
#   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
#
#   pmgrpcd and its components are Copyright (C) 2018-2019 by:
#
#   Matthias Arnold <matthias.arnold@swisscom.com>
#   Juan Camilo Cardona <jccardona82@gmail.com>
#   Thomas Graf <thomas.graf@swisscom.com>
#   Paolo Lucente <paolo@pmacct.net>
#
import sys
import os

sys.path.append(os.path.abspath('./'))

from google.protobuf.json_format import MessageToJson

import base64
import json
import sys
import telemetry_pb2
# import telemetry_top_pb2 <--.
# import logical_port_pb2  <---`- JunOS Native Telemetry

def main():
    for line in sys.stdin:
        deviceJson = json.loads(line.strip())
        #print(deviceJson)

        if "telemetry_data" not in deviceJson:
            print("No telemetry_data")
            print(deviceJson)
            continue

        telemetry_data = deviceJson["telemetry_data"]

        try:
            s = base64.b64decode(telemetry_data)
            #print(s)
        except Exception as e:
            print("Failed b64 decoding:", e)
            continue

        try:
            d = telemetry_pb2.Telemetry()
#	    d = telemetry_top_pb2.TelemetryStream() <----- JunOS Native Telemetry
            d.ParseFromString(s)
        except Exception as e:
            print("Failed GPB parsing:", len(telemetry_data), e)

        try:
            jsonStrTelemetry = MessageToJson(d)
            print(jsonStrTelemetry)
        except Exception as e:
            print("Failed Conversion to JSON:", len(telemetry_data), e)


if __name__ == "__main__":
    main()



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: huawei-grpc-dialout.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='huawei-grpc-dialout.proto',
  package='huawei_dialout',
  syntax='proto3',
  serialized_options=None,
  serialized_pb=_b('\n\x19huawei-grpc-dialout.proto\x12\x0ehuawei_dialout\":\n\x0bserviceArgs\x12\r\n\x05ReqId\x18\x01 \x01(\x03\x12\x0c\n\x04\x64\x61ta\x18\x02 \x01(\x0c\x12\x0e\n\x06\x65rrors\x18\x03 \x01(\t2`\n\x0fgRPCDataservice\x12M\n\x0b\x64\x61taPublish\x12\x1b.huawei_dialout.serviceArgs\x1a\x1b.huawei_dialout.serviceArgs\"\x00(\x01\x30\x01\x62\x06proto3')
)




_SERVICEARGS = _descriptor.Descriptor(
  name='serviceArgs',
  full_name='huawei_dialout.serviceArgs',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='ReqId', full_name='huawei_dialout.serviceArgs.ReqId', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='data', full_name='huawei_dialout.serviceArgs.data', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='errors', full_name='huawei_dialout.serviceArgs.errors', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=45,
  serialized_end=103,
)

DESCRIPTOR.message_types_by_name['serviceArgs'] = _SERVICEARGS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

serviceArgs = _reflection.GeneratedProtocolMessageType('serviceArgs', (_message.Message,), {
  'DESCRIPTOR' : _SERVICEARGS,
  '__module__' : 'huawei_grpc_dialout_pb2'
  # @@protoc_insertion_point(class_scope:huawei_dialout.serviceArgs)
  })
_sym_db.RegisterMessage(serviceArgs)



_GRPCDATASERVICE = _descriptor.ServiceDescriptor(
  name='gRPCDataservice',
  full_name='huawei_dialout.gRPCDataservice',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=105,
  serialized_end=201,
  methods=[
  _descriptor.MethodDescriptor(
    name='dataPublish',
    full_name='huawei_dialout.gRPCDataservice.dataPublish',
    index=0,
    containing_service=None,
    input_type=_SERVICEARGS,
    output_type=_SERVICEARGS,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_GRPCDATASERVICE)

DESCRIPTOR.services_by_name['gRPCDataservice'] = _GRPCDATASERVICE

# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

import gnmi_pb2 as gnmi__pb2


class gNMIStub(object):
  # missing associated documentation comment in .proto file
  pass

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.Capabilities = channel.unary_unary(
        '/gnmi.gNMI/Capabilities',
        request_serializer=gnmi__pb2.CapabilityRequest.SerializeToString,
        response_deserializer=gnmi__pb2.CapabilityResponse.FromString,
        )
    self.Get = channel.unary_unary(
        '/gnmi.gNMI/Get',
        request_serializer=gnmi__pb2.GetRequest.SerializeToString,
        response_deserializer=gnmi__pb2.GetResponse.FromString,
        )
    self.Set = channel.unary_unary(
        '/gnmi.gNMI/Set',
        request_serializer=gnmi__pb2.SetRequest.SerializeToString,
        response_deserializer=gnmi__pb2.SetResponse.FromString,
        )
    self.Subscribe = channel.stream_stream(
        '/gnmi.gNMI/Subscribe',
        request_serializer=gnmi__pb2.SubscribeRequest.SerializeToString,
        response_deserializer=gnmi__pb2.SubscribeResponse.FromString,
        )


class gNMIServicer(object):
  # missing associated documentation comment in .proto file
  pass

  def Capabilities(self, request, context):
    """Capabilities allows the client to retrieve the set of capabilities that
    is supported by the target. This allows the target to validate the
    service version that is implemented and retrieve the set of models that
    the target supports. The models can then be specified in subsequent RPCs
    to restrict the set of data that is utilized.
    Reference: gNMI Specification Section 3.2
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def Get(self, request, context):
    """Retrieve a snapshot of data from the target. A Get RPC requests that the
    target snapshots a subset of the data tree as specified by the paths
    included in the message and serializes this to be returned to the
    client using the specified encoding.
    Reference: gNMI Specification Section 3.3
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def Set(self, request, context):
    """Set allows the client to modify the state of data on the target. The
    paths to modified along with the new values that the client wishes
    to set the value to.
    Reference: gNMI Specification Section 3.4
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def Subscribe(self, request_iterator, context):
    """Subscribe allows a client to request the target to send it values
    of particular paths within the data tree. These values may be streamed
    at a particular cadence (STREAM), sent one off on a long-lived channel
    (POLL), or sent as a one-off retrieval (ONCE).
    Reference: gNMI Specification Section 3.5
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_gNMIServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'Capabilities': grpc.unary_unary_rpc_method_handler(
          servicer.Capabilities,
          request_deserializer=gnmi__pb2.CapabilityRequest.FromString,
          response_serializer=gnmi__pb2.CapabilityResponse.SerializeToString,
      ),
      'Get': grpc.unary_unary_rpc_method_handler(
          servicer.Get,
          request_deserializer=gnmi__pb2.GetRequest.FromString,
          response_serializer=gnmi__pb2.GetResponse.SerializeToString,
      ),
      'Set': grpc.unary_unary_rpc_method_handler(
          servicer.Set,
          request_deserializer=gnmi__pb2.SetRequest.FromString,
          response_serializer=gnmi__pb2.SetResponse.SerializeToString,
      ),
      'Subscribe': grpc.stream_stream_rpc_method_handler(
          servicer.Subscribe,
          request_deserializer=gnmi__pb2.SubscribeRequest.FromString,
          response_serializer=gnmi__pb2.SubscribeResponse.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'gnmi.gNMI', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))



#
#   pmacct (Promiscuous mode IP Accounting package)
#   pmacct is Copyright (C) 2003-2020 by Paolo Lucente
#
#   This program is free software; you can redistribute it and/or modify
#   it under the terms of the GNU General Public License as published by
#   the Free Software Foundation; either version 2 of the License, or
#   (at your option) any later version.
#
#   This program is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY; without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#   GNU General Public License for more details.
#
#   You should have received a copy of the GNU General Public License
#   along with this program; if not, write to the Free Software
#   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
#
#   pmgrpcd and its components are Copyright (C) 2018-2020 by:
#
#   Matthias Arnold <matthias.arnold@swisscom.com>
#   Raphaël P. Barazzutti <raphael@barazzutti.net>
#   Juan Camilo Cardona <jccardona82@gmail.com>
#   Thomas Graf <thomas.graf@swisscom.com>
#   Paolo Lucente <paolo@pmacct.net>
#
import time
from export_pmgrpcd import export_metrics

class FileInput():
    def __init__(self, filename, max_metrics_per_packet = None, time_between_packets=None):
        self.filename = filename
        self.max_metrics_per_packet = max_metrics_per_packet
        self.time_between_packets = time_between_packets

    def generate(self):
        with open(self.filename, "r") as fh:
            for line in fh:
                export_metrics(line)
                if self.time_between_packets:
                    time.sleep(self.time_between_packets)





#
#   pmacct (Promiscuous mode IP Accounting package)
#   pmacct is Copyright (C) 2003-2020 by Paolo Lucente
#
#   This program is free software; you can redistribute it and/or modify
#   it under the terms of the GNU General Public License as published by
#   the Free Software Foundation; either version 2 of the License, or
#   (at your option) any later version.
#
#   This program is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY; without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#   GNU General Public License for more details.
#
#   You should have received a copy of the GNU General Public License
#   along with this program; if not, write to the Free Software
#   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
#
#   pmgrpcd and its components are Copyright (C) 2018-2020 by:
#
#   Matthias Arnold <matthias.arnold@swisscom.com>
#   Raphaël P. Barazzutti <raphael@barazzutti.net>
#   Juan Camilo Cardona <jccardona82@gmail.com>
#   Thomas Graf <thomas.graf@swisscom.com>
#   Paolo Lucente <paolo@pmacct.net>
#
import export_pmgrpcd
import lib_pmgrpcd
from zmq_modules.zmq_exporter import ZmqExporter
from kafka_modules.kafka_avro_exporter import KafkaAvroExporter
from kafka_modules.kafka_simple_exporter import KafkaExporter
from file_modules.file_producer import FileExporter
from lib_pmgrpcd import PMGRPCDLOG

def configure(config=None):
    if config is None:
        config = lib_pmgrpcd.OPTIONS

    # Add the exporters

    if config.zmq:
        zmq_exporter = ZmqExporter()
        export_pmgrpcd.EXPORTERS["zmq"] = zmq_exporter
    if config.kafkaavro:
        kafka_avro_exporter = KafkaAvroExporter()
        export_pmgrpcd.EXPORTERS["kafkaavro"] = kafka_avro_exporter
    if config.kafkasimple:
        kafka_exporter = KafkaExporter(config.bsservers, config.topic)
        export_pmgrpcd.EXPORTERS["kafka"] = kafka_exporter
    if config.file_exporter_file is not None:
        exporter = FileExporter(config.file_exporter_file)
        export_pmgrpcd.EXPORTERS["file"] = exporter




# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: huawei-telemetry.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='huawei-telemetry.proto',
  package='telemetry',
  syntax='proto3',
  serialized_options=None,
  serialized_pb=_b('\n\x16huawei-telemetry.proto\x12\ttelemetry\"\x99\x02\n\tTelemetry\x12\x13\n\x0bnode_id_str\x18\x01 \x01(\t\x12\x1b\n\x13subscription_id_str\x18\x02 \x01(\t\x12\x13\n\x0bsensor_path\x18\x03 \x01(\t\x12\x15\n\rcollection_id\x18\x04 \x01(\x04\x12\x1d\n\x15\x63ollection_start_time\x18\x05 \x01(\x04\x12\x15\n\rmsg_timestamp\x18\x06 \x01(\x04\x12.\n\x08\x64\x61ta_gpb\x18\x07 \x01(\x0b\x32\x1c.telemetry.TelemetryGPBTable\x12\x1b\n\x13\x63ollection_end_time\x18\x08 \x01(\x04\x12\x16\n\x0e\x63urrent_period\x18\t \x01(\r\x12\x13\n\x0b\x65xcept_desc\x18\n \x01(\t\"<\n\x11TelemetryGPBTable\x12\'\n\x03row\x18\x01 \x03(\x0b\x32\x1a.telemetry.TelemetryRowGPB\"5\n\x0fTelemetryRowGPB\x12\x11\n\ttimestamp\x18\x01 \x01(\x04\x12\x0f\n\x07\x63ontent\x18\x0b \x01(\x0c\x62\x06proto3')
)




_TELEMETRY = _descriptor.Descriptor(
  name='Telemetry',
  full_name='telemetry.Telemetry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='node_id_str', full_name='telemetry.Telemetry.node_id_str', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='subscription_id_str', full_name='telemetry.Telemetry.subscription_id_str', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sensor_path', full_name='telemetry.Telemetry.sensor_path', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='collection_id', full_name='telemetry.Telemetry.collection_id', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='collection_start_time', full_name='telemetry.Telemetry.collection_start_time', index=4,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='msg_timestamp', full_name='telemetry.Telemetry.msg_timestamp', index=5,
      number=6, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='data_gpb', full_name='telemetry.Telemetry.data_gpb', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='collection_end_time', full_name='telemetry.Telemetry.collection_end_time', index=7,
      number=8, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='current_period', full_name='telemetry.Telemetry.current_period', index=8,
      number=9, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='except_desc', full_name='telemetry.Telemetry.except_desc', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=38,
  serialized_end=319,
)


_TELEMETRYGPBTABLE = _descriptor.Descriptor(
  name='TelemetryGPBTable',
  full_name='telemetry.TelemetryGPBTable',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='row', full_name='telemetry.TelemetryGPBTable.row', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=321,
  serialized_end=381,
)


_TELEMETRYROWGPB = _descriptor.Descriptor(
  name='TelemetryRowGPB',
  full_name='telemetry.TelemetryRowGPB',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='telemetry.TelemetryRowGPB.timestamp', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='content', full_name='telemetry.TelemetryRowGPB.content', index=1,
      number=11, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=383,
  serialized_end=436,
)

_TELEMETRY.fields_by_name['data_gpb'].message_type = _TELEMETRYGPBTABLE
_TELEMETRYGPBTABLE.fields_by_name['row'].message_type = _TELEMETRYROWGPB
DESCRIPTOR.message_types_by_name['Telemetry'] = _TELEMETRY
DESCRIPTOR.message_types_by_name['TelemetryGPBTable'] = _TELEMETRYGPBTABLE
DESCRIPTOR.message_types_by_name['TelemetryRowGPB'] = _TELEMETRYROWGPB
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Telemetry = _reflection.GeneratedProtocolMessageType('Telemetry', (_message.Message,), {
  'DESCRIPTOR' : _TELEMETRY,
  '__module__' : 'huawei_telemetry_pb2'
  # @@protoc_insertion_point(class_scope:telemetry.Telemetry)
  })
_sym_db.RegisterMessage(Telemetry)

TelemetryGPBTable = _reflection.GeneratedProtocolMessageType('TelemetryGPBTable', (_message.Message,), {
  'DESCRIPTOR' : _TELEMETRYGPBTABLE,
  '__module__' : 'huawei_telemetry_pb2'
  # @@protoc_insertion_point(class_scope:telemetry.TelemetryGPBTable)
  })
_sym_db.RegisterMessage(TelemetryGPBTable)

TelemetryRowGPB = _reflection.GeneratedProtocolMessageType('TelemetryRowGPB', (_message.Message,), {
  'DESCRIPTOR' : _TELEMETRYROWGPB,
  '__module__' : 'huawei_telemetry_pb2'
  # @@protoc_insertion_point(class_scope:telemetry.TelemetryRowGPB)
  })
_sym_db.RegisterMessage(TelemetryRowGPB)


# @@protoc_insertion_point(module_scope)
